@@ -31,13 +31,21 @@ def get_msg(msg) -> str:
 @weather.handle()
 async def _(bot: Bot, event: MessageEvent):
     city = get_msg(event.get_plaintext())
-    if city:
-        try:
-            data = await get_City_Weather(city)
-        except KeyError:
-            pass
-        img = draw(data)
-        b64 = img_to_b64(img)
-        await weather.finish(MessageSegment.image(b64))
-    else:
+    if city is None:
         await weather.finish("地点是...空气吗?? >_<")
+    data = await get_City_Weather(city)
+    if type(data) is int:
+        if data == 404:
+            await weather.finish()
+        else:
+            await weather.finish(f"出错了! 错误代码={data}")
+    img = draw(data) if data else None
+    b64 = img_to_b64(img) if img else None
+    if data["warning"]:
+        warning = data["warning"]["warning"]
+        text = ""
+        for i in range(len(warning)):
+            text = f'\n{warning[i]["text"]}'
+        await weather.finish(MessageSegment.image(b64) + MessageSegment.text(text))
+    else:
+        await weather.finish(MessageSegment.image(b64))
